@@ -1111,11 +1111,11 @@ class MainWindow(QtG.QMainWindow):
             return
         if event.button == 1:
             if self.moving_box is not None:
-                x = event.xdata - self.moving_box.get_width() / 2
-                y = event.ydata - self.moving_box.get_width() / 2
-                self.boxsize = self.moving_box.get_width()  # Update the current boxsize
-                self.moving_box.set_x(x)
-                self.moving_box.set_y(y)
+                x = event.xdata - self.moving_box.getRect().get_width() / 2
+                y = event.ydata - self.moving_box.getRect().get_width() / 2
+                self.boxsize = self.moving_box.getRect().get_width()  # Update the current boxsize
+                self.moving_box.getRect().set_x(x)
+                self.moving_box.getRect().set_y(y)
 
                 self.fig.canvas.restore_region(self.background_current)
 
@@ -1188,8 +1188,8 @@ class MainWindow(QtG.QMainWindow):
                 self.moving_box = rect
                 self.rectangles.append(rect)
                 # Add the patch to the Axes
-                self.ax.add_patch(rect)
-                self.ax.draw_artist(rect)
+                self.ax.add_patch(rect.getRect())
+                self.ax.draw_artist(rect.getRect())
 
                 self.fig.canvas.blit(self.ax.bbox)
                 self.unsaved_changes = True
